@@ -1,4 +1,4 @@
-/*	$Id: kcgi.h,v 1.128 2018/12/27 21:00:53 kristaps Exp $ */
+/*	$Id: kcgi.h,v 1.130 2019/08/10 08:17:34 kristaps Exp $ */
 /*
  * Copyright (c) 2012, 2014--2018 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -53,7 +53,7 @@
 /*
  * Build version.
  */
-#define	KCGI_VBUILD	10
+#define	KCGI_VBUILD	11
 
 /*
  * Version string of major.minor.build (as a literal string).
@@ -623,10 +623,10 @@ void		 kutil_invalidate(struct kreq *, struct kpair *);
 int		 kutil_openlog(const char *);
 void	 	 kutil_verr(const struct kreq *, 
 			const char *, const char *, va_list)
-			__attribute__((noreturn));
+			__attribute__((__noreturn__));
 void	 	 kutil_verrx(const struct kreq *, 
 			const char *, const char *, va_list)
-			__attribute__((noreturn));
+			__attribute__((__noreturn__));
 void		 kutil_vinfo(const struct kreq *, 
 			const char *, const char *, va_list);
 void		 kutil_vlog(const struct kreq *, const char *,
@@ -655,11 +655,11 @@ void		 kutil_warnx(const struct kreq *,
 void		 kutil_err(const struct kreq *, 
 			const char *, const char *, ...)
 			__attribute__((format(printf, 3, 4)))
-			__attribute__((noreturn));
+			__attribute__((__noreturn__));
 void		 kutil_errx(const struct kreq *, 
 			const char *, const char *, ...)
 			__attribute__((format(printf, 3, 4)))
-			__attribute__((noreturn));
+			__attribute__((__noreturn__));
 
 int		 kasprintf(char **, const char *, ...)
 			__attribute__((format(printf, 2, 3)));
